==> ezcv-0.1.1.tar.gz: ezcv-0.1.1/docs/index.md <==
![ezcv logo](https://raw.githubusercontent.com/Descent098/ezcv/master/.github/logo.png)

# Ez CV

*A python-based static site generator for setting up a CV/Resume site*

## What does ezcv do?

ezcv is a purpose built static site generator for creating personal resume/portfolio/cv sites

## Features & Roadmap

- A large collection of [built in themes](https://ezcv.readthedocs.io/en/latest/included-themes/)
- Flexible templating with Jinja2
- Fully customizable configuration files and sections
- Simple markdown syntax for content building

## Who is ezcv for?

- People who are not necessarily familiar with coding, let alone web development
- People who are familiar with web development and want a very simple to use static site generator
- People who are familiar with web development but don't want to bother writing pure html for their site

## Why should I use ezcv?

ezcv is a great choice if:

- You are fond of one of the [built in themes](https://ezcv.readthedocs.io/en/latest/included-themes/)
- You want a free and open source static site generator
- If you want a simple to use static site generator based on Jinja
- If you are familiar with markdown and yaml, and want a system that can be extended
- You are not familiar with static site generators and want a simple one to try out
- You want a static site generator with a built in github pages deploy pipeline

ezcv is not a great choice if:

- You want a widely used industry solution (something like [hugo](https://gohugo.io/) or [jekyl](https://jekyllrb.com/) would be better for this)
- You need low level access to the API for complicated extensions that are not possible within jinja
- You are not familiar with markdown, yaml and jinja and want a frontend to edit your site with ( [netlify](https://www.netlify.com/), [squarespace](https://www.squarespace.com/) or [wix](https://www.wix.com/) would be better for this)

## Getting started

See the [quick start](quick-start.md) to get started.

## Additional resources

Here are some additional resources to help you get started generating content

- [Generating avatars](https://getavataaars.com/)
- [Free open source images](https://unsplash.com/)
- [Online Vector graphics creation system](https://vectr.com/)
- [Online photo editor](https://pixlr.com/x/)

==> ezcv-0.2.2.tar.gz: ezcv-0.2.2/docs/index.md <==
![ezcv logo](https://raw.githubusercontent.com/Descent098/ezcv/master/.github/logo.png)

# Ez CV

*A python-based static site generator for setting up a CV/Resume site*

## What does ezcv do?

ezcv is a purpose built static site generator for creating personal resume/portfolio/cv sites

## Features & Roadmap

- A large collection of [built in themes](https://ezcv.readthedocs.io/en/latest/included-themes/)
- Flexible templating with Jinja2
- Fully customizable configuration files and sections
- Simple markdown syntax for content building
- Integrated HTML resume generator
- Integration with Google analytics

## Who is ezcv for?

- People who are not necessarily familiar with coding, let alone web development
- People who are familiar with web development and want a very simple to use static site generator
- People who are familiar with web development but don't want to bother writing pure html for their site

## Why should I use ezcv?

ezcv is a great choice if:

- You are fond of one of the [built in themes](https://ezcv.readthedocs.io/en/latest/included-themes/)
- You want a free and open source static site generator
- If you want a simple to use static site generator based on Jinja
- If you are familiar with markdown and yaml, and want a system that can be extended
- You are not familiar with static site generators and want a simple one to try out
- You want a static site generator with a built in github pages deploy pipeline

ezcv is not a great choice if:

- You want a widely used industry solution (something like [hugo](https://gohugo.io/) or [jekyl](https://jekyllrb.com/) would be better for this)
- You need low level access to the API for complicated extensions that are not possible within jinja
- You are not familiar with markdown, yaml and jinja and want a frontend to edit your site with ( [netlify](https://www.netlify.com/), [squarespace](https://www.squarespace.com/) or [wix](https://www.wix.com/) would be better for this)

## Getting started

See the [quick start](quick-start.md) to get started, and see be sure to check out our [discussion board](https://github.com/Descent098/ezcv/discussions) for guides and additional support.

## Additional resources

Here are some additional resources to help you get started generating content

- [Generating avatars](https://getavataaars.com/)
- [Free open source images](https://unsplash.com/)
- [Online Vector graphics creation system](https://vectr.com/)
- [Online photo editor](https://pixlr.com/x/)
